# New file built by Aero Technologies.
# This handles the new "metaflow" input CLI - which currently references S3OP

import click


@click.group(help="Aero's Core commandset")
def cli():
    pass
